Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PipelineSyncer ¶
type PipelineSyncer interface {
Sync()
}
type RadarSchedulerFactory ¶
type RadarSchedulerFactory interface {
BuildScanRunnerFactory(dbPipeline dbng.Pipeline, externalURL string) radar.ScanRunnerFactory
BuildScheduler(pipeline dbng.Pipeline, externalURL string) scheduler.BuildScheduler
}
func NewRadarSchedulerFactory ¶
func NewRadarSchedulerFactory( resourceFactory resource.ResourceFactory, interval time.Duration, engine engine.Engine, ) RadarSchedulerFactory
type SyncRunner ¶
type SyncRunner struct {
Syncer PipelineSyncer
Interval time.Duration
Clock clock.Clock
}
Directories
¶
| Path | Synopsis |
|---|---|
|
This file was generated by counterfeiter This file was generated by counterfeiter
|
This file was generated by counterfeiter This file was generated by counterfeiter |
Click to show internal directories.
Click to hide internal directories.